#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <glib.h>
#include <glib/gi18n.h>
#include <audacious/util.h>
#include "about.h"

struct developer
{
  char *name;
  char *email;
};

struct translator
{
  char *language;
  char *abbr;
  char *name;
  char *email;
};

static struct developer developers[] = {
  {"Mark Raddatz", "mark@xnull.de"},
  {"Phil Rendell", "prr1@aber.ac.uk"},
  {"Michal Bialoskorski", "skorka@task.gda.pl"},
  {"Eoin Coffey", "ecoffey@gmail.com"},
  {"Peter Polonkai", "polesz@nedudu.hu"},
  {NULL, NULL}
};

static struct translator translators[] = {
  {N_("German"), "de", "Mark Raddatz", "mark@xnull.de"},
  {N_("French"), "fr", "David Le Brun", "david@dyn-ns.net"},
  {N_("Italian"), "it", "Alessio D'Ascanio", "g3ntaro@fastwebnet.it"},
  {N_("Japanese"), "ja", "Nobuyuki Ito", "nobu.1026@gmail.com"},
  {N_("Polish"), "pl", "Jacek Wolszczak", "shutdownrunner@o2.pl"},
  {N_("Hungarian"), "hu", "Peter Polonkai", "polesz@nedudu.hu"},
  {NULL, NULL, NULL, NULL}
};

void
docklet_plugin_about (void)
{
  static GtkWidget *about_dialog;
  GString *str;
  int i;

  if (about_dialog != NULL)
    return;

#ifdef ENABLE_NLS
  setlocale (LC_ALL, "");
  bindtextdomain (PACKAGE, LOCALE_DIR);
  bind_textdomain_codeset (PACKAGE, "UTF-8");
  textdomain (PACKAGE);
#endif

  str = g_string_sized_new (384);
  g_string_printf (str, _("Audacious Player Docklet Plugin %s\n\n"),
                   VERSION);
  g_string_append_printf (str,
                          _
                          ("Displays a system tray icon (in GNOME or KDE for example) to allow\n"
                           "fast access to commonly used functions, and to toggle display of\n"
                           "the Audacious Player window.\n\n"));
  g_string_append_printf (str, "URL: %s\n\n",
                          "http://nedudu.hu/en");

  g_string_append_printf (str, "%s:\n", _("Developers"));
  for (i = 0; developers[i].name != NULL; i++)
    {
      g_string_append_printf (str, "%s", developers[i].name);
      if (developers[i].email != NULL)
        g_string_append_printf (str, " <%s>", developers[i].email);
      g_string_append_printf (str, "\n");
    }
  g_string_append_printf (str, "\n");

  g_string_append_printf (str, "%s:\n", _("Translators"));
  for (i = 0; translators[i].language != NULL; i++)
    {
      g_string_append_printf (str, "%s (%s) - %s", _(translators[i].language),
                              translators[i].abbr, translators[i].name);
      if (translators[i].email != NULL)
        g_string_append_printf (str, " <%s>", translators[i].email);
      g_string_append_printf (str, "\n");
    }
  g_string_append_printf (str, "\n");

  about_dialog =
    bmp_info_dialog (_("About Audacious Player Docklet"), str->str, "Close",
                     FALSE, NULL, NULL);
  g_string_free (str, TRUE);

  g_signal_connect (G_OBJECT (about_dialog), "destroy",
                    G_CALLBACK (gtk_widget_destroyed), &about_dialog);
}
